# Changelog

## [0.0.33a7](https://github.com/OpenVoiceOS/ovos-utils/tree/0.0.33a7) (2023-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a6...0.0.33a7)

**Fixed bugs:**

- Configurable skills base directory [\#143](https://github.com/OpenVoiceOS/ovos-utils/pull/143) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.33a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a6) (2023-05-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a5...V0.0.33a6)

**Implemented enhancements:**

- port LF time utils [\#141](https://github.com/OpenVoiceOS/ovos-utils/pull/141) ([emphasize](https://github.com/emphasize))

## [V0.0.33a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a5) (2023-05-01)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a4...V0.0.33a5)

**Implemented enhancements:**

- feat/skill\_api [\#139](https://github.com/OpenVoiceOS/ovos-utils/pull/139) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.33a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a4) (2023-05-01)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a3...V0.0.33a4)

**Fixed bugs:**

- fix/new\_bug [\#138](https://github.com/OpenVoiceOS/ovos-utils/pull/138) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- Moving ovos-bus-client to requirements.txt? [\#137](https://github.com/OpenVoiceOS/ovos-utils/issues/137)

**Merged pull requests:**

- codecov [\#136](https://github.com/OpenVoiceOS/ovos-utils/pull/136) ([JarbasAl](https://github.com/JarbasAl))
- codecov automation [\#135](https://github.com/OpenVoiceOS/ovos-utils/pull/135) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.33a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a3) (2023-04-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a2...V0.0.33a3)

**Fixed bugs:**

- fix/core\_root\_location [\#134](https://github.com/OpenVoiceOS/ovos-utils/pull/134) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.33a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a2) (2023-04-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a1...V0.0.33a2)

## [V0.0.33a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a1) (2023-04-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.32...V0.0.33a1)

**Implemented enhancements:**

- feat/padatious\_samples\_in\_bus [\#133](https://github.com/OpenVoiceOS/ovos-utils/pull/133) ([JarbasAl](https://github.com/JarbasAl))

**Merged pull requests:**

- Enable release action [\#131](https://github.com/OpenVoiceOS/ovos-utils/pull/131) ([NeonDaniel](https://github.com/NeonDaniel))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
